from .base_model import *


class LbrComplexResearchType(BaseModel):
    """
    Комплексные исследования
    """

    id = models.AutoField(db_column="ComplexResearchTypeID", primary_key=True)
    guid = models.CharField(db_column="Guid", max_length=36, unique=True)
    research_type = models.ForeignKey(
        "LbrResearchType", db_column="rf_ResearchTypeGuid", to_field="uguid", **FK_DEFAULT
    )
    complex_research_type = models.ForeignKey(
        "LbrComplexResearchType", db_column="rf_ComplexResearchTypeGuid", to_field="guid", **FK_DEFAULT
    )
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_ComplexResearchType"



from .base_model import *


class OmsKlResearchProfile(BaseModel):
    id = models.AutoField(db_column="kl_ResearchProfileID", primary_key=True)
    guid = models.CharField(db_column="ResearchProfileGuid", unique=True, max_length=36)
    code = models.CharField(db_column="Code", max_length=20)
    name = models.CharField(db_column="Name", max_length=500)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    description = models.CharField(db_column="Description", max_length=500)

    class Meta:
        managed = False
        db_table = "oms_kl_ResearchProfile"



from .base_model import *


class LbrResearchTypeKind(BaseModel):
    """
    Вид исследования
    """

    id = models.AutoField(db_column="ResearchTypeKindID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    code = models.CharField(db_column="Code", max_length=20)
    description = models.CharField(db_column="Description", max_length=8000)
    name = models.CharField(db_column="Name", max_length=200)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    flags = models.IntegerField(db_column="Flags")
    lab_direction_type = models.ForeignKey("LbrLabDirectionType", db_column="rf_LabDirectionTypeID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeKind"



from .base_model import *


class HltDispResultValue(BaseModel):
    """
    Результат прохождения обследования
    """

    id = models.AutoField(db_column="disp_ResultValueID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=100)
    name = models.TextField(db_column="Name")
    guid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
    flags = models.IntegerField(db_column="Flags", default=0)
    rf_card_guid = models.CharField(
        db_column="rf_CardGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    result_type = models.ForeignKey(
        "HltDispResultType",
        models.DO_NOTHING,
        to_field="guid",
        db_column="rf_ResultTypeGuid",
        max_length=36,
    )
    result_type_value = models.ForeignKey(
        "HltDispResultTypeValue",
        models.DO_NOTHING,
        to_field="guid",
        db_column="rf_ResultTypeValueGuid",
        max_length=36,
    )
    value1 = models.TextField(db_column="Value1", default="")
    value2 = models.DecimalField(db_column="Value2", max_digits=9, decimal_places=4, default="0.0")
    document_id = models.IntegerField(db_column="DocumentId", default=0)
    doc_type_guid = models.CharField(
        db_column="DocTypeGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    tap = models.ForeignKey("HltTap", models.DO_NOTHING, db_column="rf_TAPID", related_name="+")
    is_auto = models.BooleanField(db_column="IsAuto", default=False)
    rf_exam_guid = models.CharField(
        db_column="rf_ExamGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )

    class Meta:
        managed = False
        db_table = "hlt_disp_ResultValue"



from .base_model import *


class LbrOption(BaseModel):
    """
    Справочник опций выбора биоматериала
    """

    id = models.AutoField(db_column="OptionID", primary_key=True)
    guid = models.CharField(db_column="GUID", unique=True, max_length=36)
    is_required = models.BooleanField(db_column="IsRequired")
    max = models.IntegerField(db_column="Max")
    min = models.IntegerField(db_column="Min")
    name = models.CharField(db_column="Name", max_length=255)
    unit = models.CharField(db_column="Unit", max_length=100)
    option_value_type = models.ForeignKey("LbrOptionValueType", db_column="rf_OptionValueTypeID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_Option"



from .base_model import *


class LbrResearchTypeToProfile(BaseModel):
    """
    Профиль по типу исследования
    """

    id = models.AutoField(db_column="ResearchTypeToProfileID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", unique=True, max_length=36)
    research_profile_id = models.IntegerField(db_column="rf_kl_ResearchProfileID")
    research_type = models.ForeignKey("LbrResearchType", db_column="rf_ResearchTypeID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeToProfile"



from .base_model import *


class LbrResearchJournal(BaseModel):
    """
    Журнал обследований
    """

    id = models.AutoField(db_column="ResearchJournalID", primary_key=True)
    action_date = models.DateTimeField(db_column="ActionDate")
    comment = models.TextField(db_column="Comment")
    hl7_message = models.TextField(db_column="HL7Message")
    research = models.ForeignKey(
        "LbrResearch", db_column="rf_ResearchGUID", to_field="guid", max_length=36, **FK_DEFAULT
    )
    research_state = models.ForeignKey("LbrResearchState", db_column="rf_ResearchStateID", **FK_DEFAULT)
    laboratory_research = models.ForeignKey("LbrLaboratoryResearch", db_column="rf_LaboratoryResearchID", **FK_DEFAULT)
    client_application_guid = models.CharField(db_column="rf_ClientApplicationGuid", max_length=36)

    class Meta:
        managed = False
        db_table = "lbr_ResearchJournal"



from .base_model import *


class LbrResearchService(BaseModel):
    """
    Услуга исследования
    """

    id = models.AutoField(db_column="ResearchServiceID", primary_key=True)
    flag = models.IntegerField(db_column="Flag")
    guid = models.CharField(db_column="GUID", max_length=36)
    research = models.ForeignKey(
        "LbrResearch", db_column="rf_ResearchGUID", to_field="guid", max_length=36, **FK_DEFAULT
    )
    service_medical = models.ForeignKey("OmsServiceMedical", db_column="rf_ServiceMedicalID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_ResearchService"



from .base_model import *


class LbrLaboratoryResearchPack(BaseModel):
    """
    Пакет направлений
    """

    id = models.AutoField(db_column="LaboratoryResearchPackID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    name = models.CharField(db_column="Name", max_length=300)
    prvs = models.ForeignKey("self", db_column="rf_PRVSID", **FK_DEFAULT)
    flags = models.IntegerField(db_column="Flags")
    user = models.ForeignKey("XUser", db_column="rf_UserID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_LaboratoryResearchPack"



from .base_model import *


class LbrResearchTypeParamToResearchType(BaseModel):
    """
    Связь между параметрами и типами исследований
    """

    id = models.AutoField(db_column="ResearchTypeParamToResearchTypeID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    research_type = models.ForeignKey("LbrResearchType", db_column="rf_ResearchTypeID", **FK_DEFAULT)
    research_type_param = models.ForeignKey("LbrResearchTypeParam", db_column="rf_ResearchTypeParamID", **FK_DEFAULT)
    date_end = models.DateTimeField(db_column="DateEnd")
    date_begin = models.DateTimeField(db_column="DateBegin")
    sort = models.IntegerField(db_column="Sort")

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeParamToResearchType"



from .base_model import *


class LbrHistologicalBlock(BaseModel):
    """
    Гистологический блок
    """

    id = models.AutoField(db_column="HistologicalBlockID", primary_key=True)
    guid = models.CharField(db_column="Guid", unique=True, max_length=36)
    number = models.CharField(db_column="Number", max_length=50)
    sample = models.CharField(db_column="Sample", max_length=200)
    in_archive = models.BooleanField(db_column="InArchive")
    research = models.ForeignKey(
        "LbrResearch", db_column="rf_ResearchGUID", to_field="guid", max_length=36, **FK_DEFAULT
    )
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_HistologicalBlock"



from .base_model import *


class LbrResearchTypeParamInPack(BaseModel):
    """
    Параметр в составе пакета
    """

    id = models.AutoField(db_column="ResearchTypeParamInPackID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    research_type_in_pack = models.ForeignKey(
        "LbrResearchTypeInPack", db_column="rf_ResearchTypeInPackID", **FK_DEFAULT
    )
    research_type_param = models.ForeignKey("LbrResearchTypeParam", db_column="rf_ResearchTypeParamID", **FK_DEFAULT)
    required_param = models.BooleanField(db_column="RequiredParam")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeParamInPack"



from .base_model import *


class OmsKlNomServiceMkbMse(BaseModel):
    id = models.AutoField(db_column="kl_NomServiceMkbMseID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=50)
    is_main = models.BooleanField(db_column="IsMain")
    name = models.CharField(db_column="Name", max_length=1000)
    nom_service_mkb_mse_guid = models.CharField(db_column="NomServiceMkbMseGuid", unique=True, max_length=36)
    nom_service = models.ForeignKey("OmsKlNomService", models.DO_NOTHING, db_column="rf_kl_NomServiceID")
    mkb = models.ForeignKey("OmsMkb", models.DO_NOTHING, db_column="rf_MKBID")
    is_child = models.BooleanField(db_column="IsChild")
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")

    class Meta:
        managed = False
        db_table = "oms_kl_NomServiceMkbMse"



"""
Модель OmsKlVisitPlace - Место оказания медицинской помощи

Эта модель работает с таблицей oms_kl_VisitPlace, которая может иметь разную структуру
в различных базах данных. В некоторых базах отсутствуют поля CodeEGISZ и NameEGISZ.

Для управления совместимостью используйте настройку в settings.py:
TMMIS_OMS_KL_VISIT_PLACE_HAS_EGISZ_FIELDS = True/False

Примеры использования:

1. В settings.py вашего проекта:
   # Для баз с полями ЕГИСЗ
   TMMIS_OMS_KL_VISIT_PLACE_HAS_EGISZ_FIELDS = True

   # Для баз без полей ЕГИСЗ
   TMMIS_OMS_KL_VISIT_PLACE_HAS_EGISZ_FIELDS = False

2. Использование в коде (одинаково для всех версий):
   place = OmsKlVisitPlace.objects.get(id=1)
   print(place.code_egisz)  # Всегда работает

3. Фильтрация:
   places = OmsKlVisitPlace.objects.filter(code_egisz="123")  # Работает!
"""

from django.conf import settings

from .base_model import *


class OmsKlVisitPlace(BaseModel):
    id = models.AutoField(db_column="kl_VisitPlaceID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=50, default="не определено")
    name = models.CharField(db_column="Name", max_length=255, default="не определено")
    date_b = models.DateTimeField(db_column="Date_B", default="1900-01-01")
    date_e = models.DateTimeField(db_column="Date_E", default="2222-01-01")

    # Поля ЕГИСЗ - добавляются условно в зависимости от настроек
    is_tap = models.BooleanField(db_column="IsTAP", default=False)
    guid = models.CharField(db_column="VisitPlaceGUID", max_length=36, default=uuid4)

    class Meta:
        managed = False
        db_table = "oms_kl_VisitPlace"


# Условное добавление полей ЕГИСЗ в зависимости от настроек
if getattr(settings, "TMMIS_OMS_KL_VISIT_PLACE_HAS_EGISZ_FIELDS", False):
    # Добавляем поля ЕГИСЗ динамически
    OmsKlVisitPlace.add_to_class("code_egisz", models.CharField(db_column="CodeEGISZ", max_length=50, default=""))
    OmsKlVisitPlace.add_to_class("name_egisz", models.CharField(db_column="NameEGISZ", max_length=255, default=""))
else:
    # Добавляем заглушки для совместимости
    def _get_empty_egisz_field(self):
        return ""

    OmsKlVisitPlace.code_egisz = property(_get_empty_egisz_field)
    OmsKlVisitPlace.name_egisz = property(_get_empty_egisz_field)



from .base_model import *


class OmsKlMetIssl(BaseModel):
    """
    Классификатор методов диагностического исследования (V029)
    """

    id = models.AutoField(db_column="kl_MetIsslID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=10)
    name = models.CharField(db_column="Name", max_length=200)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    description = models.TextField(db_column="Description")
    flags = models.IntegerField(db_column="Flags")
    guid = models.CharField(db_column="Guid", max_length=36)

    class Meta:
        managed = False
        db_table = "oms_kl_MetIssl"



from .base_model import *


class OmsKlDiagnosType(BaseModel):
    """
    Тип диагноза
    """

    id = models.AutoField(db_column="kl_DiagnosTypeID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=50)
    date_b = models.DateTimeField(db_column="Date_B")
    date_e = models.DateTimeField(db_column="Date_E")
    guid_diagnos_type = models.CharField(db_column="GUIDDiagnosType", max_length=36)
    name = models.CharField(db_column="Name", max_length=255)
    department_type_id = models.ForeignKey("OmsKlDepartmentType", db_column="rf_kl_DepartmentTypeID", **FK_DEFAULT)
    code_egisz = models.IntegerField(db_column="CodeEgisz")
    description = models.CharField(db_column="Description", max_length=255)

    class Meta:
        managed = False
        db_table = "oms_kl_DiagnosType"



from .base_model import *


class LbrResearchSample(BaseModel):
    """
    Проба
    """

    id = models.AutoField(db_column="ResearchSampleID", primary_key=True)
    uguid = models.CharField(db_column="UGuid", unique=True, max_length=36)
    barcode = models.CharField(db_column="BarCode", max_length=50)
    count = models.DecimalField(db_column="Count", max_digits=10, decimal_places=3)
    date = models.DateTimeField(db_column="Date")
    bio_m_id = models.IntegerField(db_column="rf_BioMID")
    research = models.ForeignKey("LbrResearch", db_column="rf_ResearchID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    laboratory_research = models.ForeignKey(
        "LbrLaboratoryResearch", db_column="rf_LaboratoryResearchGUID", to_field="guid", **FK_DEFAULT
    )
    print_labels_count = models.IntegerField(db_column="PrintLabelsCount")

    class Meta:
        managed = False
        db_table = "lbr_ResearchSample"



from .base_model import *


class XDocTypeDef(BaseModel):
    id = models.AutoField(db_column="DocTypeDefID", primary_key=True)
    name = models.CharField(db_column="Name", max_length=50)
    mnem_code = models.CharField(db_column="MnemCode", max_length=50)
    caption = models.CharField(db_column="Caption", max_length=50)
    description = models.CharField(db_column="Description", max_length=500)
    head_table = models.CharField(db_column="HeadTable", max_length=50, **NULL)
    pk_name = models.CharField(db_column="PK_Name", max_length=50, **NULL)
    tag_name = models.CharField(db_column="TagName", max_length=50, **NULL)
    to_string = models.IntegerField(db_column="ToString")
    theme_id = models.IntegerField(db_column="ThemeID")
    guid = models.CharField(db_column="GUID", max_length=36)
    type = models.IntegerField(db_column="Type")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "x_DocTypeDef"



from .base_model import *


class HltDispResultTypeValue(BaseModel):
    """
    Значения типов результата
    """

    id = models.AutoField(db_column="disp_ResultTypeValueID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=100)
    name = models.TextField(db_column="Name")
    guid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
    date_begin = models.DateTimeField(db_column="DateBegin", default=timezone.now)
    date_end = models.DateTimeField(db_column="DateEnd", default=timezone.datetime(2222, 1, 1))
    flags = models.IntegerField(db_column="Flags", default=0)
    rf_disp_type_guid = models.CharField(
        db_column="rf_DispTypeGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    result_type = models.ForeignKey(
        "HltDispResultType",
        models.DO_NOTHING,
        to_field="guid",
        db_column="rf_ResultTypeGuid",
        max_length=36,
    )
    rf_variant_guid = models.CharField(
        db_column="rf_VariantGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    point = models.DecimalField(db_column="Point", max_digits=18, decimal_places=2, default="0.0")

    class Meta:
        managed = False
        db_table = "hlt_disp_ResultTypeValue"



from .base_model import *


class LbrResearchState(BaseModel):
    """
    Состояние обследования
    """

    id = models.AutoField(db_column="ResearchStateID", primary_key=True)
    description = models.TextField(db_column="Description")
    enum_name = models.CharField(db_column="EnumName", max_length=50)

    class Meta:
        managed = False
        db_table = "lbr_ResearchState"



from .base_model import *


class LbrOptionValue(BaseModel):
    """
    Таблица значений опции
    """

    id = models.AutoField(db_column="OptionValueID", primary_key=True)
    guid = models.CharField(db_column="Guid", unique=True, max_length=36)
    option = models.ForeignKey("LbrOption", db_column="rf_OptionID", **FK_DEFAULT)
    sample_id = models.IntegerField(db_column="rf_SampleID")
    value = models.TextField(db_column="Value")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_OptionValue"



from .base_model import *


class HltCitizen(BaseModel):
    """
    Место жительства
    """

    id = models.AutoField(db_column="CitizenID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36)
    cod = models.SmallIntegerField(db_column="COD")
    name = models.CharField(db_column="NAME", max_length=50)
    date_in = models.DateTimeField(db_column="DATEIN")
    date_out = models.DateTimeField(db_column="DATEOUT")
    date_edit = models.DateTimeField(db_column="DateEDIT")

    class Meta:
        managed = False
        db_table = "hlt_Citizen"



from .base_model import *


class LbrLaboratoryResearch(BaseModel):
    """
    Лабораторное исследование
    """

    id = models.AutoField(db_column="LaboratoryResearchID", primary_key=True)
    guid = models.CharField(db_column="GUID", max_length=36, unique=True)
    date_direction = models.DateTimeField(db_column="Date_Direction")
    doct_fio = models.CharField(db_column="DOCT_FIO", max_length=200)
    doct_pcod = models.CharField(db_column="DOCT_PCOD", max_length=20)
    flag = models.IntegerField(db_column="Flag")
    flag_unload = models.IntegerField(db_column="FlagUnload")
    number = models.CharField(db_column="Number", max_length=100)
    pat_birthday = models.DateTimeField(db_column="Pat_Birthday")
    pat_family = models.CharField(db_column="Pat_Family", max_length=100)
    pat_name = models.CharField(db_column="Pat_Name", max_length=100)
    pat_ot = models.CharField(db_column="Pat_Ot", max_length=100)
    pat_w = models.BooleanField(db_column="Pat_W")
    priority = models.BooleanField(db_column="Priority")
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    laboratory = models.ForeignKey("LbrLaboratory", db_column="rf_LaboratoryID", **FK_DEFAULT)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    medical_history_old_id = models.IntegerField(db_column="rf_MedicalHistoryOldID")
    mkab = models.ForeignKey("HltMkab", db_column="rf_MKABID", **FK_DEFAULT)
    mkb = models.ForeignKey("OmsMkb", db_column="rf_MKBID", **FK_DEFAULT)
    tap = models.ForeignKey("HltTap", db_column="rf_TAPID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    smo = models.ForeignKey("OmsLpu", db_column="rf_SMOID", **FK_DEFAULT)
    tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
    pat_s_pol = models.CharField(db_column="Pat_S_POL", max_length=50)
    pat_n_pol = models.CharField(db_column="Pat_N_POL", max_length=50)
    lpu_sender_id = models.IntegerField(db_column="rf_LPUSenderID")
    comment = models.CharField(db_column="Comment", max_length=5000)
    profit_type = models.ForeignKey("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
    is_read_only = models.BooleanField(db_column="isReadOnly")
    research_cause = models.ForeignKey("LbrLabResearchCause", db_column="rf_LabResearchCauseID", **FK_DEFAULT)
    lab_research_target = models.ForeignKey("LbrLabResearchTarget", db_column="rf_LabResearchTargetID", **FK_DEFAULT)
    lpu = models.ForeignKey("OmsLpu", db_column="rf_LPUID", **FK_DEFAULT)
    date_create = models.DateTimeField(db_column="DateCreate")
    accession_number = models.CharField(db_column="AccessionNumber", max_length=100)
    doct_d_prvd_guid = models.CharField(db_column="DOCT_DPRVDGUID", max_length=36)
    lab_research_contingent_id = models.IntegerField(db_column="rf_LabResearchContingentID")
    medical_history_id = models.IntegerField(db_column="rf_MedicalHistoryID")
    additional_comment = models.CharField(db_column="AdditionalComment", max_length=1000)
    previous_research_results = models.CharField(db_column="PreviousResearchResults", max_length=1000)
    is_previous_research_performed = models.BooleanField(db_column="IsPreviousResearchPerformed")
    previous_treatment = models.CharField(db_column="PreviousTreatment", max_length=1000)
    is_previous_treatment_performed = models.BooleanField(db_column="IsPreviousTreatmentPerformed")
    department_sender_name = models.CharField(db_column="DepartmentSenderName", max_length=255)
    pat_ss = models.CharField(db_column="Pat_SS", max_length=14)
    doct_ss = models.CharField(db_column="DOCT_SS", max_length=14)
    doct_phone = models.CharField(db_column="DOCT_PHONE", max_length=25)
    cancel_comment = models.TextField(db_column="CancelComment")
    cancel_reason_id = models.IntegerField(db_column="rf_CancelReasonID")
    lab_direction_type = models.ForeignKey("LbrLabDirectionType", db_column="rf_LabDirectionTypeID", **FK_DEFAULT)
    visit_other_lpu_id = models.ForeignKey("OmsLpu", db_column="rf_VisitOtherLpuID", **FK_DEFAULT)
    direction_status_id = models.IntegerField(db_column="rf_DirectionStatusId")
    clinical_diagnos = models.CharField(db_column="ClinicalDiagnos", max_length=2000)
    lpu_other = models.ForeignKey("OmsLpu", db_column="rf_LPUOtherID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_LaboratoryResearch"



from .base_model import *


class LbrLabResearchTarget(BaseModel):
    """
    Цель исследования
    """

    id = models.AutoField(db_column="LabResearchTargetID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=50)
    name = models.CharField(db_column="Name", max_length=200)
    description = models.CharField(db_column="Description", max_length=250)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_LabResearchTarget"



from .base_model import *


class HltHealingRoom(BaseModel):
    """
    Кабинет
    """

    id = models.AutoField(db_column="HealingRoomID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36)
    num = models.CharField(db_column="Num", max_length=50)
    comment = models.CharField(db_column="Comment", max_length=50)
    flat = models.IntegerField(db_column="Flat")
    in_time = models.IntegerField(db_column="InTime")
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    date_actualization = models.DateTimeField(db_column="DateActualization")
    oid = models.CharField(db_column="OID", max_length=50)

    class Meta:
        managed = False
        db_table = "hlt_HealingRoom"



from .base_model import *


class LbrResearchType(BaseModel):
    """
    Классификатор исследований
    """

    id = models.AutoField(db_column="ResearchTypeID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    code = models.CharField(db_column="Code", max_length=50)
    period = models.IntegerField(db_column="Period")
    report = models.TextField(db_column="Report")
    name = models.CharField(db_column="ResearchName", max_length=8000)
    bio_mid = models.IntegerField(db_column="rf_BioMID")
    type = models.ForeignKey("LbrLaboratoryType", db_column="rf_LaboratoryTypeID", **FK_DEFAULT)
    research_type_kind = models.ForeignKey("LbrResearchTypeKind", db_column="rf_ResearchTypeKindID", **FK_DEFAULT)
    service_medical = models.ForeignKey("OmsServiceMedical", db_column="rf_ServiceMedicalID", **FK_DEFAULT)
    flags = models.IntegerField(db_column="Flags")
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    nom_service = models.ForeignKey("OmsKlNomService", db_column="rf_kl_NomServiceID", **FK_DEFAULT)
    is_complex = models.BooleanField(db_column="IsComplex")
    norm_duration = models.IntegerField(db_column="NormDuration")
    met_issl = models.ForeignKey("OmsKlMetIssl", db_column="rf_kl_MetIsslID", **FK_DEFAULT)
    component = models.CharField(db_column="Component", max_length=500)
    localization = models.CharField(db_column="Localization", max_length=500)
    body_area = models.CharField(db_column="BodyArea", max_length=500)
    rf_diagnostic_type_guid = models.CharField(db_column="rf_DiagnosticTypeGUID", max_length=36)

    class Meta:
        managed = False
        db_table = "lbr_ResearchType"



from .base_model import *


class LbrLaboratoryResearchInPack(BaseModel):
    """
    Направление в составе пакета
    """

    id = models.AutoField(db_column="LaboratoryResearchInPackID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    pack = models.ForeignKey("LbrLaboratoryResearchPack", db_column="rf_LaboratoryResearchPackID", **FK_DEFAULT)
    laboratory = models.ForeignKey("LbrLaboratory", db_column="rf_LaboratoryID", **FK_DEFAULT)
    lpu = models.ForeignKey("OmsLpu", db_column="rf_LPUID", **FK_DEFAULT)
    research_cause = models.ForeignKey("LbrLabResearchCause", db_column="rf_LabResearchCauseID", **FK_DEFAULT)
    lab_research_target = models.ForeignKey("LbrLabResearchTarget", db_column="rf_LabResearchTargetID", **FK_DEFAULT)
    lab_research_contingent_id = models.IntegerField(db_column="rf_LabResearchContingentID")
    priority = models.BooleanField(db_column="Priority")
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_LaboratoryResearchInPack"



from .base_model import *


class LbrResearchTypeInPack(BaseModel):
    """
    Исследование в составе пакета
    """

    id = models.AutoField(db_column="ResearchTypeInPackID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    research_type = models.ForeignKey(
        "LbrResearchType", db_column="rf_ResearchTypeGuid", to_field="uguid", **FK_DEFAULT
    )
    flags = models.IntegerField(db_column="Flags")
    laboratory_research_in_pack = models.ForeignKey(
        "LbrLaboratoryResearchInPack", db_column="rf_LaboratoryResearchInPackID", **FK_DEFAULT
    )

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeInPack"



from .base_model import *


class LbrOptionEnumValues(BaseModel):
    """
    Вариант значений опций биоматериала
    """

    id = models.AutoField(db_column="OptionEnumValuesID", primary_key=True)
    guid = models.CharField(db_column="Guid", unique=True, max_length=36)
    value = models.CharField(db_column="Value", max_length=500)
    option = models.ForeignKey("LbrOption", db_column="rf_OptionID", **FK_DEFAULT)
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_OptionEnumValues"



from .base_model import *


class XDocElemDef(BaseModel):
    id = models.AutoField(db_column="DocElemDefID", primary_key=True)
    type_def = models.ForeignKey("XDocTypeDef", db_column="DocTypeDefID", **FK_DEFAULT)
    name = models.CharField(db_column="Name", max_length=50)
    mnem_code = models.CharField(db_column="MnemCode", max_length=50)
    caption = models.CharField(db_column="Caption", max_length=500)
    description = models.CharField(db_column="Description", max_length=500)
    elem_type = models.IntegerField(db_column="ElemType")
    value_type = models.IntegerField(db_column="ValueType")
    value_size = models.IntegerField(db_column="ValueSize")
    value_scale = models.IntegerField(db_column="ValueScale")
    field_name = models.CharField(db_column="FieldName", max_length=2500)
    linked_doc_type_def_id = models.IntegerField(db_column="LinkedDocTypeDefID")
    linked_doc_elem_def_id = models.IntegerField(db_column="LinkedDocElemDefID")
    access_def = models.IntegerField(db_column="AccessDef", **NULL)
    tag_name = models.CharField(db_column="TagName", max_length=50)
    delete_mode = models.IntegerField(db_column="DeleteMode", **NULL)
    show_mode = models.IntegerField(db_column="ShowMode", **NULL)
    srv_doc_elem_def_id = models.IntegerField(db_column="SRVDocElemDefID")
    guid = models.CharField(db_column="GUID", max_length=36)
    pos = models.IntegerField(db_column="Pos")
    outputformat = models.CharField(db_column="OutputFormat", max_length=50)
    flags = models.IntegerField(db_column="Flags")
    category_name = models.CharField(db_column="CategoryName", max_length=50)
    sql_data_type = models.CharField(db_column="SqlDataType", max_length=50)

    class Meta:
        managed = False
        db_table = "x_DocElemDef"



from .base_model import *


class LbrOptionValueType(BaseModel):
    """
    Тип данных опции
    """

    id = models.AutoField(db_column="OptionValueTypeID", primary_key=True)
    guid = models.CharField(db_column="Guid", unique=True, max_length=36)
    code = models.CharField(db_column="Code", max_length=50)
    name = models.CharField(db_column="Name", max_length=200)
    enum_name = models.CharField(db_column="EnumName", max_length=50)
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_OptionValueType"



from .base_model import *


class LbrLaboratory(BaseModel):
    """
    Лаборатория
    """

    id = models.AutoField(db_column="LaboratoryID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    url = models.CharField(db_column="LaboratoryURL", max_length=4000)
    department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
    type = models.ForeignKey("LbrLaboratoryType", db_column="rf_LaboratoryTypeID", **FK_DEFAULT)
    name = models.CharField(db_column="LaboratoryName", max_length=255)
    kind = models.ForeignKey("LbrLaboratoryKind", db_column="rf_LaboratoryKindID", **FK_DEFAULT)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")

    class Meta:
        managed = False
        db_table = "lbr_Laboratory"



from .base_model import *


class HltDispResultType(BaseModel):
    """
    Тип результатов заключения
    """

    id = models.AutoField(db_column="disp_ResultTypeID", primary_key=True)
    code = models.CharField(db_column="Code", max_length=100, default="")
    name = models.TextField(db_column="Name")
    guid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
    date_begin = models.DateTimeField(db_column="DateBegin", default=timezone.now)
    date_end = models.DateTimeField(db_column="DateEnd", default=timezone.datetime(2222, 1, 1))
    flags = models.IntegerField(db_column="Flags", default=0)
    rf_disp_type_guid = models.CharField(
        db_column="rf_DispTypeGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    is_main = models.BooleanField(db_column="IsMain", default=False)
    is_show_ctrl = models.SmallIntegerField(db_column="IsShowCtrl", default=0)
    age_from = models.IntegerField(db_column="AgeFrom", default=0)
    age_to = models.IntegerField(db_column="AgeTo", default=0)
    sex_id = models.IntegerField(db_column="rf_kl_SexID", default=0)
    rf_result_type_display_id = models.IntegerField(db_column="rf_ResultTypeDisplayID", default=0)
    rf_disp_question_type_id = models.IntegerField(db_column="rf_disp_QuestionTypeID", default=0)
    rf_mkbid = models.IntegerField(db_column="rf_MKBID", default=0)
    rf_question_guid = models.CharField(
        db_column="rf_QuestionGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )

    class Meta:
        managed = False
        db_table = "hlt_disp_ResultType"



from .atf_file_attachment import AtfFileAttachment
from .atf_file_info import AtfFileInfo
from .atf_file_type import AtfFileType
from .hlt_blank_template import HltBlankTemplate
from .hlt_call_doctor import HltCallDoctor
from .hlt_call_doctor_status import HltCallDoctorStatus
from .hlt_citizen import HltCitizen
from .hlt_disp_result_type import HltDispResultType
from .hlt_disp_result_type_value import HltDispResultTypeValue
from .hlt_disp_result_value import HltDispResultValue
from .hlt_doc_prvd import HltDocPrvd
from .hlt_doctor_time_table import HltDoctorTimeTable
from .hlt_doctor_visit_table import HltDoctorVisitTable
from .hlt_healing_room import HltHealingRoom
from .hlt_lpu_doctor import HltLpuDoctor
from .hlt_med_record import HltMedRecord
from .hlt_mkab import Gender, HltMkab
from .hlt_mkb_tap import HltMkbTap
from .hlt_polis_mkab import HltPolisMkab
from .hlt_reason_care import HltReasonCare
from .hlt_representative_mkab import HltRepresentativeMkab
from .hlt_smtap import HltSmTap
from .hlt_tap import HltTap
from .hlt_type_call_doctor import HltTypeCallDoctor
from .hlt_uchastok import HltUchastok
from .hlt_visit_history import HltVisitHistory
from .kla_address import KlaAddress
from .kla_house import KlaHouse
from .kla_kladr import KlaKladr
from .kla_street import KlaStreet
from .lbr_complex_research_type import LbrComplexResearchType
from .lbr_histological_block import LbrHistologicalBlock
from .lbr_lab_direction_type import LbrLabDirectionType
from .lbr_lab_research_cause import LbrLabResearchCause
from .lbr_lab_research_target import LbrLabResearchTarget
from .lbr_laboratory import LbrLaboratory
from .lbr_laboratory_kind import LbrLaboratoryKind
from .lbr_laboratory_research import LbrLaboratoryResearch
from .lbr_laboratory_research_in_pack import LbrLaboratoryResearchInPack
from .lbr_laboratory_research_pack import LbrLaboratoryResearchPack
from .lbr_laboratory_research_type import LbrLaboratoryResearchType
from .lbr_laboratory_type import LbrLaboratoryType
from .lbr_option import LbrOption
from .lbr_option_enum_values import LbrOptionEnumValues
from .lbr_option_value import LbrOptionValue
from .lbr_option_value_type import LbrOptionValueType
from .lbr_research import LbrResearch
from .lbr_research_journal import LbrResearchJournal
from .lbr_research_param_value_type import LbrResearchParamValueType
from .lbr_research_param_values import LbrResearchParamValues
from .lbr_research_result import LbrResearchResult
from .lbr_research_sample import LbrResearchSample
from .lbr_research_service import LbrResearchService
from .lbr_research_state import LbrResearchState
from .lbr_research_type import LbrResearchType
from .lbr_research_type_in_pack import LbrResearchTypeInPack
from .lbr_research_type_kind import LbrResearchTypeKind
from .lbr_research_type_kind_doc_prvd import LbrResearchTypeKindDocPRVD
from .lbr_research_type_param import LbrResearchTypeParam
from .lbr_research_type_param_in_pack import LbrResearchTypeParamInPack
from .lbr_research_type_param_to_research_type import LbrResearchTypeParamToResearchType
from .lbr_research_type_to_lpu import LbrResearchTypeToLpu
from .lbr_research_type_to_profile import LbrResearchTypeToProfile
from .oms_department import OmsDepartment
from .oms_kl_age_group import OmsKlAgeGroup
from .oms_kl_dd_service import OmsKlDDService
from .oms_kl_department_profile import OmsKlDepartmentProfile
from .oms_kl_department_type import OmsKlDepartmentType
from .oms_kl_diagnos_type import OmsKlDiagnosType
from .oms_kl_disease_type import OmsKlDiseaseType
from .oms_kl_health_group import OmsKlHealthGroup
from .oms_kl_med_care_type import OmsKlMedCareType
from .oms_kl_met_issl import OmsKlMetIssl
from .oms_kl_nom_lpu import OmsKlNomLPU
from .oms_kl_nom_service import OmsKlNomService
from .oms_kl_nom_service_mkb_mse import OmsKlNomServiceMkbMse
from .oms_kl_profit_type import OmsKlProfitType
from .oms_kl_reason_type import OmsKlReasonType
from .oms_kl_research_profile import OmsKlResearchProfile
from .oms_kl_soc_status import OmsKlSocStatus
from .oms_kl_stat_cure_result import OmsKlStatCureResult
from .oms_kl_tip_oms import OmsKlTipOms
from .oms_kl_visit_place import OmsKlVisitPlace
from .oms_kl_visit_result import OmsKlVisitResult
from .oms_lpu import OmsLpu
from .oms_mkb import OmsMkb
from .oms_okato import OmsOkato
from .oms_okved import OmsOkved
from .oms_organisation import OmsOrganisation
from .oms_prvd import OmsPrvd
from .oms_prvs import OmsPrvs
from .oms_service_medical import OmsServiceMedical
from .oms_smo import OmsSmo
from .oms_type_doc import OmsTypedoc
from .x_doc_elem_def import XDocElemDef
from .x_doc_type_def import XDocTypeDef
from .x_user import XUser

__all__ = [
    "AtfFileAttachment",
    "AtfFileInfo",
    "AtfFileType",
    "Gender",
    "HltBlankTemplate",
    "HltCallDoctor",
    "HltCallDoctorStatus",
    "HltCitizen",
    "HltDispResultType",
    "HltDispResultTypeValue",
    "HltDispResultValue",
    "HltDocPrvd",
    "HltDoctorTimeTable",
    "HltDoctorVisitTable",
    "HltHealingRoom",
    "HltLpuDoctor",
    "HltMedRecord",
    "HltMkab",
    "HltMkbTap",
    "HltPolisMkab",
    "HltReasonCare",
    "HltRepresentativeMkab",
    "HltSmTap",
    "HltTap",
    "HltTypeCallDoctor",
    "HltUchastok",
    "HltVisitHistory",
    "KlaAddress",
    "KlaHouse",
    "KlaKladr",
    "KlaStreet",
    "LbrComplexResearchType",
    "LbrHistologicalBlock",
    "LbrLabDirectionType",
    "LbrLabResearchCause",
    "LbrLabResearchTarget",
    "LbrLaboratory",
    "LbrLaboratoryKind",
    "LbrLaboratoryResearch",
    "LbrLaboratoryResearchInPack",
    "LbrLaboratoryResearchPack",
    "LbrLaboratoryResearchType",
    "LbrLaboratoryType",
    "LbrOption",
    "LbrOptionEnumValues",
    "LbrOptionValue",
    "LbrOptionValueType",
    "LbrResearch",
    "LbrResearchJournal",
    "LbrResearchParamValueType",
    "LbrResearchParamValues",
    "LbrResearchResult",
    "LbrResearchSample",
    "LbrResearchService",
    "LbrResearchState",
    "LbrResearchType",
    "LbrResearchTypeInPack",
    "LbrResearchTypeKind",
    "LbrResearchTypeKindDocPRVD",
    "LbrResearchTypeParam",
    "LbrResearchTypeParamInPack",
    "LbrResearchTypeParamToResearchType",
    "LbrResearchTypeToLpu",
    "LbrResearchTypeToProfile",
    "OmsDepartment",
    "OmsKlAgeGroup",
    "OmsKlDDService",
    "OmsKlDepartmentProfile",
    "OmsKlDepartmentType",
    "OmsKlDiagnosType",
    "OmsKlDiseaseType",
    "OmsKlHealthGroup",
    "OmsKlMedCareType",
    "OmsKlMetIssl",
    "OmsKlNomLPU",
    "OmsKlNomService",
    "OmsKlNomServiceMkbMse",
    "OmsKlProfitType",
    "OmsKlReasonType",
    "OmsKlResearchProfile",
    "OmsKlSocStatus",
    "OmsKlStatCureResult",
    "OmsKlTipOms",
    "OmsKlVisitPlace",
    "OmsKlVisitResult",
    "OmsLpu",
    "OmsMkb",
    "OmsOkato",
    "OmsOkved",
    "OmsOrganisation",
    "OmsPrvd",
    "OmsPrvs",
    "OmsServiceMedical",
    "OmsSmo",
    "OmsTypedoc",
    "XDocElemDef",
    "XDocTypeDef",
    "XUser",
]



from .base_model import *


class LbrResearchResult(BaseModel):
    """
    Результаты исследования
    """

    id = models.AutoField(db_column="ResearchResultID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    caption = models.CharField(db_column="Caption", max_length=200)
    date_complete = models.DateTimeField(db_column="DateComplete")
    ext_link = models.CharField(db_column="ExtLink", max_length=4000)
    href = models.CharField(db_column="HRef", max_length=100)
    l_ref = models.CharField(db_column="LRef", max_length=100)
    r_boolean = models.BooleanField(db_column="rBoolean")
    r_datetime = models.DateTimeField(db_column="rDateTime")
    r_decimal = models.DecimalField(db_column="rDecimal", max_digits=18, decimal_places=2)
    required_param = models.BooleanField(db_column="RequiredParam")
    research = models.ForeignKey(
        "LbrResearch", db_column="rf_ResearchGUID", to_field="guid", max_length=36, **FK_DEFAULT
    )
    research_param_value_type = models.ForeignKey(
        "LbrResearchParamValueType", db_column="rf_ResearchParamValueTypeID", **FK_DEFAULT
    )
    research_type_param = models.ForeignKey(
        "LbrResearchTypeParam", db_column="rf_ResearchTypeParamUGUID", to_field="uguid", **FK_DEFAULT
    )
    r_integer = models.IntegerField(db_column="rInteger")
    r_string = models.TextField(db_column="rString")
    test_note = models.TextField(db_column="TestNote")
    unit = models.CharField(db_column="Unit", max_length=100)
    value = models.TextField(db_column="Value")
    is_addition = models.BooleanField(db_column="IsAddition")
    r_guid = models.CharField(db_column="rGUID", max_length=36)
    is_deviation = models.BooleanField(db_column="IsDeviation")

    class Meta:
        managed = False
        db_table = "lbr_ResearchResult"



from .base_model import *


class LbrResearchParamValues(BaseModel):
    """
    Вариант значений параметра
    """

    id = models.AutoField(db_column="ResearchParamValuesID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    research_type_param = models.ForeignKey(
        "LbrResearchTypeParam", db_column="rf_ResearchTypeParamUGUID", to_field="uguid", **FK_DEFAULT
    )
    value = models.CharField(db_column="Value", max_length=8000)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")
    code = models.CharField(db_column="Code", max_length=100)

    class Meta:
        managed = False
        db_table = "lbr_ResearchParamValues"



from .base_model import *


class LbrResearchTypeKindDocPRVD(BaseModel):
    """
    Вид исследования и ресурсы
    """

    id = models.AutoField(db_column="ResearchTypeKindDocPRVDID", primary_key=True)
    uguid = models.CharField(db_column="UGuid", unique=True, max_length=36)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    research_type_kind = models.ForeignKey("LbrResearchTypeKind", db_column="rf_ResearchTypeKindID", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeKindDocPRVD"



from .base_model import *


class HltMedRecord(BaseModel):
    id = models.AutoField(db_column="MedRecordID", primary_key=True)
    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
    confidentiality_code = models.CharField(db_column="ConfidentialityCode", max_length=50, default="")
    crc = models.TextField(db_column="CRC", default="")
    data = models.TextField(db_column="Data", default="")
    date = models.DateTimeField(db_column="Date", default=timezone.now)
    blank_template = models.ForeignKey("HltBlankTemplate", db_column="rf_BlankTemplateID", **FK_DEFAULT)
    lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
    visit_history = models.ForeignKey(
        "HltVisitHistory", models.DO_NOTHING, db_column="rf_VisitHistoryID", related_name="med_records", default=0
    )
    sign = models.TextField(db_column="Sign", default="Sign")
    event_data_time = models.DateTimeField(db_column="EventDataTime", default=timezone.now)
    person = models.ForeignKey("HltMkab", db_column="PersonGUID", to_field="uuid", **FK_DEFAULT)
    doc = models.CharField(
        db_column="rf_DOCGUID",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    doc_type_def = models.CharField(
        db_column="rf_DocTypeDefGUID",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    view_data = models.TextField(db_column="ViewData")
    create_username = models.CharField(db_column="CreateUserName", max_length=255, default="")
    edit_username = models.CharField(db_column="EditUserName", max_length=255, default="")
    create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
    edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
    desc = models.CharField(
        db_column="DescGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    create_date = models.DateTimeField(db_column="CreateDate", default=timezone.now)
    description = models.TextField(db_column="Description", default="")
    doc_prvd = models.CharField(
        db_column="rf_DocPrvdGuid",
        max_length=36,
        default="00000000-0000-0000-0000-000000000000",
    )
    # mkab = models.ForeignKey("HltMkab", db_column="rf_MKABGuid", to_field="uuid", **FK_DEFAULT)
    is_upload = models.BooleanField(db_column="isUpload", default=False)
    is_del = models.BooleanField(db_column="IsDel", default=False)

    flags = models.IntegerField(db_column="Flags", default=0)

    class Meta:
        managed = False
        db_table = "hlt_MedRecord"



from .base_model import *


class LbrResearch(BaseModel):
    """
    Исследование
    """

    id = models.AutoField(db_column="ResearchID", primary_key=True)
    guid = models.CharField(db_column="GUID", max_length=36, unique=True)
    date_complete = models.DateTimeField(db_column="Date_Complete")
    flag = models.IntegerField(db_column="Flag")
    is_complete = models.BooleanField(db_column="isComplete")
    lab_doct_fio = models.CharField(db_column="LAB_DOCT_FIO", max_length=200)
    lab_doct_pcod = models.CharField(db_column="LAB_DOCT_PCOD", max_length=20)
    number = models.CharField(db_column="Number", max_length=100)
    doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LabDoctorID", **FK_DEFAULT)
    laboratory_research = models.ForeignKey(
        "LbrLaboratoryResearch",
        db_column="rf_LaboratoryResearchGUID",
        to_field="guid",
        **FK_DEFAULT,
    )
    medical_history_id = models.IntegerField(db_column="rf_MedicalHistoryID")
    prev_research_guid = models.CharField(db_column="rf_PrevResearchGUID", max_length=36)
    research_type = models.ForeignKey(
        "LbrResearchType",
        db_column="rf_ResearchTypeUGUID",
        to_field="uguid",
        **FK_DEFAULT,
    )
    tap = models.ForeignKey("HltTap", db_column="rf_TAPID", **FK_DEFAULT)
    doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
    comment = models.TextField(db_column="Comment")
    is_performed = models.BooleanField(db_column="IsPerformed")
    date_performed = models.DateTimeField(db_column="DatePerformed")
    conclusion = models.TextField(db_column="Conclusion")
    performed_doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_PerformedDocPRVDID", **FK_DEFAULT)
    is_canceled = models.BooleanField(db_column="isCanceled")
    study_uid = models.CharField(db_column="StudyUID", max_length=100)
    performed_doc_fio = models.CharField(db_column="PerformedDocFio", max_length=100)
    performed_doc_p_code = models.CharField(db_column="PerformedDocPCode", max_length=20)
    date_registred = models.DateTimeField(db_column="DateRegistred")
    date_receipt = models.DateTimeField(db_column="DateReceipt")
    is_issued = models.BooleanField(db_column="IsIssued")
    date_issued = models.DateTimeField(db_column="DateIssued")
    issued_by_doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_IssuedByDocPRVDID", **FK_DEFAULT)
    issued_to_lpu = models.ForeignKey("OmsLpu", db_column="rf_IssuedToLPUID", **FK_DEFAULT)
    issued_to_person = models.CharField(db_column="IssuedToPerson", max_length=200)
    is_registred = models.BooleanField(db_column="IsRegistred")
    is_receipt = models.BooleanField(db_column="IsReceipt")
    consult_doctor_fio = models.CharField(db_column="ConsultDoctorFio", max_length=200)
    is_manual_data = models.BooleanField(db_column="IsManualData")
    is_iemk_data = models.BooleanField(db_column="IsIemkData")
    is_main_expert = models.BooleanField(db_column="IsMainExpert")
    performed_lpu_name = models.CharField(db_column="PerformedLpuName", max_length=250)
    performed_laboratory = models.ForeignKey(
        "LbrLaboratory",
        db_column="rf_PerformedLaboratoryGUID",
        to_field="uguid",
        **FK_DEFAULT,
    )
    performed_department = models.ForeignKey(
        "OmsDepartment",
        db_column="rf_PerformedDepartmentGUID",
        to_field="uuid",
        **FK_DEFAULT,
    )
    is_rejected = models.BooleanField(db_column="isRejected")
    clinical_diagnos = models.CharField(db_column="ClinicalDiagnos", max_length=2000)
    is_complete_early = models.BooleanField(db_column="IsCompleteEarly")
    lpu_complete_early_guid = models.CharField(db_column="rf_LpuCompleteEarlyGUID", max_length=36)
    lpu_other_complete_early_guid = models.CharField(db_column="rf_LpuOtherCompleteEarlyGUID", max_length=36)
    research_profile = models.ForeignKey("OmsKlResearchProfile", db_column="rf_kl_ResearchProfileID", **FK_DEFAULT)
    consult_doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_ConsultDocPRVDID", **FK_DEFAULT)
    url = models.CharField(db_column="Url", max_length=1000)
    effective_dose = models.DecimalField(db_column="EffectiveDose", max_digits=10, decimal_places=4)
    date_end_performed = models.DateTimeField(db_column="DateEndPerformed")
    cancel_reason = models.CharField(db_column="CancelReason", max_length=500)
    cancel_doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_CancelDocPRVDID", **FK_DEFAULT)
    rf_lpu_performed_guid = models.CharField(db_column="rf_LPUPerformedGUID", max_length=36)
    rf_lpu_other_performed_guid = models.CharField(db_column="rf_LPUOtherPerformedGUID", max_length=36)
    rf_lpu_complete_guid = models.CharField(db_column="rf_LPUCompleteGUID", max_length=36)
    rf_lpu_other_complete_guid = models.CharField(db_column="rf_LPUOtherCompleteGUID", max_length=36)
    lab_comment = models.CharField(db_column="LabComment", max_length=1000)
    second_opinion_status = models.IntegerField(db_column="SecondOpinionStatus")
    lpu_second_opinion = models.ForeignKey(
        "OmsLpu",
        db_column="rf_LPUSecondOpinionGUID",
        to_field="uuid",
        **FK_DEFAULT,
    )
    cancel_doc_fio = models.CharField(db_column="CancelDocFio", max_length=200)
    cancel_doc_p_code = models.CharField(db_column="CancelDocPCode", max_length=20)

    class Meta:
        managed = False
        db_table = "lbr_Research"



from .base_model import *


class LbrResearchTypeParam(BaseModel):
    """
    Параметры типа исследования
    """

    id = models.AutoField(db_column="ResearchTypeParamID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", max_length=36, unique=True)
    code = models.CharField(db_column="Code", max_length=50)
    code_lis = models.CharField(db_column="CodeLis", max_length=50)
    flags = models.IntegerField(db_column="Flags")
    group_name = models.CharField(db_column="GroupName", max_length=200)
    max_normal_value = models.DecimalField(db_column="MaxNormalValue", max_digits=11, decimal_places=7)
    maxvalue = models.DecimalField(db_column="MaxValue", max_digits=11, decimal_places=7)
    min_normal_value = models.DecimalField(db_column="MinNormalValue", max_digits=11, decimal_places=7)
    minvalue = models.DecimalField(db_column="MinValue", max_digits=11, decimal_places=7)
    param_name = models.CharField(db_column="ParamName", max_length=255)
    param_unit = models.CharField(db_column="ParamUnit", max_length=200)
    required_param = models.BooleanField(db_column="RequiredParam")
    bio_m_id = models.IntegerField(db_column="rf_BioMID")
    microbe_id = models.IntegerField(db_column="rf_MicrobeID")
    research_param_value_type = models.ForeignKey(
        "LbrResearchParamValueType", db_column="rf_ResearchParamValueTypeID", **FK_DEFAULT
    )
    research_type = models.ForeignKey(
        "LbrResearchType", db_column="rf_ResearchTypeUGUID", to_field="uguid", **FK_DEFAULT
    )
    service_medical = models.ForeignKey("OmsServiceMedical", db_column="rf_ServiceMedicalID", **FK_DEFAULT)
    shortname = models.CharField(db_column="ShortName", max_length=212)
    template_param_name = models.CharField(db_column="TemplateParamName", max_length=200)
    date_begin = models.DateTimeField(db_column="DateBegin")
    date_end = models.DateTimeField(db_column="DateEnd")

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeParam"



from .base_model import *


class LbrLaboratoryResearchType(BaseModel):
    """
    Исследования, выполняемые лабораторией
    """

    id = models.AutoField(db_column="LaboratoryResearchTypeID", primary_key=True)
    guid = models.CharField(db_column="GUID", max_length=36, unique=True)
    laboratory = models.ForeignKey("LbrLaboratory", db_column="rf_LaboratoryID", **FK_DEFAULT)
    research_type = models.ForeignKey(
        "LbrResearchType", db_column="rf_ResearchTypeUGUID", to_field="uguid", **FK_DEFAULT
    )
    flags = models.IntegerField(db_column="Flags")

    class Meta:
        managed = False
        db_table = "lbr_LaboratoryResearchType"



from .base_model import *


class LbrResearchParamValueType(BaseModel):
    """
    Тип параметра
    """

    id = models.AutoField(db_column="ResearchParamValueTypeID", primary_key=True)
    code = models.IntegerField(db_column="Code")
    enum_name = models.CharField(db_column="EnumName", max_length=50)
    name = models.CharField(db_column="Name", max_length=8000)

    class Meta:
        managed = False
        db_table = "lbr_ResearchParamValueType"



from .base_model import *


class LbrResearchTypeToLpu(BaseModel):
    """
    Справочник проводимых исследований в ЛПУ
    """

    id = models.AutoField(db_column="ResearchTypeToLpuID", primary_key=True)
    uguid = models.CharField(db_column="UGUID", unique=True, max_length=36)
    research_type = models.ForeignKey(
        "LbrResearchType", db_column="rf_ResearchTypeUGUID", to_field="uguid", **FK_DEFAULT
    )
    lpu = models.ForeignKey("OmsLpu", to_field="uuid", db_column="rf_LPUGuid", **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = "lbr_ResearchTypeToLpu"
